package hw.tagApi.system.mapper;

import java.util.List;
import hw.tagApi.system.domain.SysAttachInfo;

/**
 * 附件信息Mapper接口
 * 
 * @author Yinq
 * @date 2025-04-22
 */
public interface SysAttachInfoMapper 
{
    /**
     * 查询附件信息
     * 
     * @param attachId 附件信息主键
     * @return 附件信息
     */
    public SysAttachInfo selectSysAttachInfoByAttachId(Long attachId);

    /**
     * 查询附件信息列表
     * 
     * @param sysAttachInfo 附件信息
     * @return 附件信息集合
     */
    public List<SysAttachInfo> selectSysAttachInfoList(SysAttachInfo sysAttachInfo);

    /**
     * 新增附件信息
     * 
     * @param sysAttachInfo 附件信息
     * @return 结果
     */
    public int insertSysAttachInfo(SysAttachInfo sysAttachInfo);

    /**
     * 修改附件信息
     * 
     * @param sysAttachInfo 附件信息
     * @return 结果
     */
    public int updateSysAttachInfo(SysAttachInfo sysAttachInfo);

    /**
     * 删除附件信息
     * 
     * @param attachId 附件信息主键
     * @return 结果
     */
    public int deleteSysAttachInfoByAttachId(Long attachId);

    /**
     * 批量删除附件信息
     * 
     * @param attachIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysAttachInfoByAttachIds(Long[] attachIds);
}
